@@ -5,6 +5,10 @@ from fastapi import FastAPI
 
 from .endpoints import register_endpoints
 from .jobs import JobManager
+from .monitoring_endpoints import (
+    MonitoringWebSocketManager,
+    create_monitoring_endpoints,
+)
 from .websocket_handler import register_websocket_routes
 
 
@@ -15,12 +19,10 @@ def create_websocket_app(job_manager: JobManager, progress_dir: Path) -> FastAPI
         version="1.0.0",
     )
 
-    # Store job_manager in app state for startup/shutdown events
     app.state.job_manager = job_manager
 
     @app.on_event("startup")
     async def startup_event() -> None:
-        """Start background tasks."""
         if job_manager:
             asyncio.create_task(job_manager.monitor_progress_files())
             asyncio.create_task(job_manager.cleanup_old_jobs())
@@ -28,7 +30,6 @@ def create_websocket_app(job_manager: JobManager, progress_dir: Path) -> FastAPI
 
     @app.on_event("shutdown")
     async def shutdown_event() -> None:
-        """Cleanup on shutdown."""
         if job_manager:
             job_manager.cleanup()
 
@@ -36,4 +37,8 @@ def create_websocket_app(job_manager: JobManager, progress_dir: Path) -> FastAPI
 
     register_websocket_routes(app, job_manager, progress_dir)
 
+    # Register monitoring endpoints
+    monitoring_ws_manager = MonitoringWebSocketManager()
+    create_monitoring_endpoints(app, job_manager, progress_dir, monitoring_ws_manager)
+
     return app
